{"": "", "stdin data": "stdin data", "Run arbitrary scripts": "Executar scripts arbitr\u00e1rios", "Run": "Executar", "Name": "Nome", "Copy terminal content": "Copiar conte\u00fado do terminal", "Script": "Script", "Terminate": "Terminar", "Terminal": "Terminal", "Terminals": "Terminais", "Done": "Conclu\u00eddo", "Open shell terminals": "Abrir um novo terminal", "Run a command...": "Execute um comando...", "Open a new terminal": "Abrir um novo terminal"}