{"": "", "stdin data": "data stdin", "Run arbitrary scripts": "Jalankan script yang sewenang-wenang", "Run": "Menjalankan", "Name": "Nama", "Copy terminal content": "Salin isi terminal", "Script": "Naskah", "Terminate": "Mengakhiri", "Terminal": "Terminal", "Terminals": "Terminal", "Done": "Selesai", "Open shell terminals": "Buka terminal shell", "Run a command...": "Jalankan perintah...", "Open a new terminal": "Buka terminal baru"}