{"": "", "stdin data": "donn\u00e9es stdin", "Run arbitrary scripts": "Ex\u00e9cuter des scripts arbitraires", "Run": "Ex\u00e9cuter", "Name": "Nom", "Copy terminal content": "Copier le contenu du terminal", "Script": "Script", "Terminate": "Terminer", "Terminal": "Terminal", "Terminals": "Terminals", "Done": "Effectu\u00e9", "Open shell terminals": "Ouvrir un terminal shell", "Run a command...": "Ex\u00e9cuter une commande...", "Open a new terminal": "Ouvrir un nouveau terminal"}