{"": "", "stdin data": "", "Run arbitrary scripts": "\uc784\uc758\uc758 \uc2a4\ud06c\ub9bd\ud2b8 \uc2e4\ud589", "Run": "\uc2e4\ud589", "Name": "\uc774\ub984", "Copy terminal content": "\ud130\ubbf8\ub110 \ub0b4\uc6a9 \ubcf5\uc0ac", "Script": "\uc2a4\ud06c\ub9bd\ud2b8", "Terminate": "\uac15\uc81c\uc885\ub8cc", "Terminal": "\ud130\ubbf8\ub110", "Terminals": "\ud130\ubbf8\ub110", "Done": "\uc644\ub8cc", "Open shell terminals": "\uc258 \ud130\ubbf8\ub110 \uc5f4\uae30", "Run a command...": "\uba85\ub839\uc5b4 \uc2e4\ud589...", "Open a new terminal": "\uc0c8 \ud130\ubbf8\ub110 \uc5f4\uae30"}