{"": "", "stdin data": "entrada de datos est\u00e1ndar", "Run arbitrary scripts": "Ejecutar archivos de comandos arbitrarios", "Run": "Ejecutar", "Name": "Nombre", "Copy terminal content": "Copiar contenido de la terminal", "Script": "Archivos de comandos", "Terminate": "Finalizar", "Terminal": "Terminal", "Terminals": "Terminales", "Done": "Finalizado", "Open shell terminals": "Abrir terminales shell", "Run a command...": "Ejecutar un comando...", "Open a new terminal": "Abrir una nueva terminal"}