{"": "", "stdin data": "stdin verisi", "Run arbitrary scripts": "Rastgele komut dosyas\u0131 \u00e7al\u0131\u015ft\u0131r", "Run": "\u00c7al\u0131\u015ft\u0131r", "Name": "Ad\u0131", "Copy terminal content": "Terminal i\u00e7eri\u011fini kopyala", "Script": "Script", "Terminate": "Sonland\u0131r", "Terminal": "Terminal", "Terminals": "Terminaller", "Done": "Bitti", "Open shell terminals": "U\u00e7birimi a\u00e7", "Run a command...": "Bir komut \u00e7al\u0131\u015ft\u0131r\u0131n...", "Open a new terminal": "Yeni terminal a\u00e7"}