{"": "", "stdin data": "Dane stdin", "Run arbitrary scripts": "Uruchom dowolne skrypty", "Run": "Uruchom", "Name": "Nazwa", "Copy terminal content": "Kopiowanie tre\u015bci terminala", "Script": "Skrypt", "Terminate": "Przerwij", "Terminal": "Terminal", "Terminals": "Terminale", "Done": "Wykonane", "Open shell terminals": "Otw\u00f3rz pow\u0142ok\u0119 terminala", "Run a command...": "Uruchom polecenie...", "Open a new terminal": "Otw\u00f3rz nowy terminal"}