{"": "", "stdin data": "stdin data", "Run arbitrary scripts": "Esegui uno script arbitrario", "Run": "Esegui", "Name": "Nome", "Copy terminal content": "Copia il contenuto dal terminale", "Script": "Script", "Terminate": "Termina", "Terminal": "Terminale", "Terminals": "Terminali", "Done": "Chiudi", "Open shell terminals": "Apri un terminale shell", "Run a command...": "Esegui un comando...", "Open a new terminal": "Apri un nuovo terminale"}