{"": "", "stdin data": "stdin podatki", "Run arbitrary scripts": "Za\u017eeni poljubne skripte", "Run": "Za\u017eeni", "Name": "Ime", "Copy terminal content": "Kopiraj vsebino terminala", "Script": "Skripta", "Terminate": "Prekini", "Terminal": "Terminal", "Terminals": "Terminali", "Done": "Kon\u010dano", "Open shell terminals": "Odprti terminali lupine", "Run a command...": "Za\u017eeni ukaz...", "Open a new terminal": "Odpri nov terminal"}