{"": "", "stdin data": "stdin adat", "Run arbitrary scripts": "Tetsz\u0151leges parancsf\u00e1jlok futtat\u00e1sa", "Run": "Fut\u00e1s", "Name": "N\u00e9v", "Copy terminal content": "Termin\u00e1l tartalom m\u00e1sol\u00e1sa", "Script": "Szkript", "Terminate": "Befejez\u00e9s", "Terminal": "Termin\u00e1l", "Terminals": "Termin\u00e1lok", "Done": "K\u00e9sz", "Open shell terminals": "", "Run a command...": "Parancs futtat\u00e1sa...", "Open a new terminal": "\u00daj termin\u00e1l"}